==> nextcloud-14.0.13.zip: nextcloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Esto generalmente se soluciona dándole al servidor web acceso para escribir en el directorio config. ",
    "See %s" : "Ver %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Favor de ver %s",
    "Sample configuration detected" : "Se ha detectado la configuración de muestra",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que la configuración de muestra ha sido copiada. Esto puede descomponer su instalacón y no está soportado. Favor de leer la documentación antes de hacer cambios en el archivo config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de Groupware",
    "Social sharing bundle" : "Paquete para compartir en redes sociales",
    "PHP %s or higher is required." : "Se requiere de PHPH %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferiror a la %s es requerido. ",
    "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
    "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
    "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
    "The library %s is not available." : "La biblioteca %s no está disponible. ",
    "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
    "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
    "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Favor de habilitarlo en sus configuraciones de aplicación o contacte a su administrador.  ",
    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
    "__language_name__" : "Español (Argentina)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
    "Help" : "Ayuda",
    "Apps" : "Aplicaciones",
    "Log out" : "Cerrar sesión",
    "Users" : "Usuarios",
    "Unknown user" : "Ususario desconocido",
    "Basic settings" : "Configuraciones  básicas",
    "Sharing" : "Compartiendo",
    "Security" : "Seguridad",
    "Additional settings" : "Configuraciones adicionales",
    "%s enter the database username and name." : "%s ingrese el nombre del usuario y nombre de la base de datos",
    "%s enter the database username." : "%s ingresar el nombre de usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s no puede utilizar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña de Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "El nombre de usuario y/o contraseña de PostgreSQL inválidos",
    "You need to enter details of an existing account." : "Necesita ingresar los detalles de una cuenta existente.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Uselo bajo su propio riesgo!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, favor de cosiderar usar en su lugar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Favor de eliminar el ajuste open_basedir de su archivo php.ini o cambie a PHP de 64 bits. ",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Establecer la contraseña del administrador.",
    "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
    "Invalid Federated Cloud ID" : "ID de Nube Federada Inválido",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
    "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
    "You are not allowed to share %s" : "No tiene permitido compartir %s",
    "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el nombre de usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre del usuario contiene un espacio en blanco al inicio o al final",
    "Username must not consist of dots only" : "El nombre de usuario no debe consistir de solo puntos. ",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The username is already being used" : "Ese nombre de usuario ya está en uso",
    "User disabled" : "Usuario deshabilitado",
    "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, favor de intentarlo más tarde. ",
    "Can't read file" : "No se puede leer el archivo",
    "Application is not enabled" : "La aplicación está deshabilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "La ficha ha expirado. Favor de recarga la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuenta con controladores de base de datos (sqlite, mysql o postgresql)  instalados. ",
    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio de las aplicaciones o deshabilitando la appstore en el archivo config. Favor de ver %s",
    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Favor de ver %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Favor de ver %s.",
    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
    "Please install one of these locales on your system and restart your webserver." : "Favor de instalar uno de las siguientes configuraciones locales en su sistema y reinicie su servidor web",
    "Please ask your server administrator to install the module." : "Favor de solicitar a su adminsitrador la instalación del módulo. ",
    "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establezca <code>mbstring.func_overload</code> a <code>0</code> en su archivo php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s esta instalado. ",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, favor de actualizar la versión de su libxml2 y reinicie su servidor web. ",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
    "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
    "Please upgrade your database version" : "Favor de actualizar la versión de la base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
    "Your data directory is readable by other users" : "Su direcctorio data puede ser leído por otros usuarios",
    "Your data directory must be an absolute path" : "Su direcctorio data debe ser una ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Verifique el valor de \"datadirectory\" en su configuración",
    "Your data directory is invalid" : "Su directorio de datos es inválido",
    "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
    "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
    "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
    "Library %s with a version higher than %s is required - available version %s." : "La biblitoteca %s con una versión superiror a la %s es requerida - versión disponible %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Se requiere de la biblioteca %s con una versión inferiror a la %s - la versión %s está disponible. ",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Se presentó una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %i",
    "Sharing %s failed, because the file does not exist" : "Se presentó una falla al compartir %s porque el archivo no existe",
    "Sharing %s failed, because you can not share with yourself" : "Se presento una falla al compartir %s, porque no puede compartir con usted mismo",
    "Sharing %s failed, because the user %s does not exist" : "Se presentó una falla al compartir %s porque el usuario %s no existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se presentó una falla al compartir %s proque el usuario %s no es un miembro de ninguno de los grupos de los cuales %s es miembro",
    "Sharing %s failed, because this item is already shared with %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
    "Sharing %s failed, because the group %s does not exist" : "Se presentó una falla al compartir %s, porque el grupo %s no existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Se presentó una falla al compartir %s debido a que %s no es un miembro del grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Usted necesita proporcionar una contraseña para crear un link público, sólo los links protegidos están permitidos. ",
    "Sharing %s failed, because sharing with links is not allowed" : "Se presentó una falla al compartir %s porque no está permitido compartir con links",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elemento compartido federado con el mismo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se presentó una falla al compartir %s, no fue posible encontrar %s, tal vez el servidor sea inalcanzable por el momento",
    "Share type %s is not valid for %s" : "El tipo del elemento compartido %s no es válido para %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No ha sido posible establecer la fecha de expiración. Los recursos compartidos no pueden expirar después de %s tras haber sido compartidos",
    "Cannot set expiration date. Expiration date is in the past" : "No ha sido posible establecer la fecha de expiración. La fecha de expiración ya ha pasado",
    "Sharing failed, because the user %s is the original sharer" : "Se presento una falla al compartir, porque el usuario %s es quien compartió originalmente",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se presentó una falla al compartir %s, porque los permisos exceden los permisos otorgados a %s",
    "Sharing %s failed, because resharing is not allowed" : "Falla al compartir %s debído a que no se permite volver a compartir",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se presentó una falla al compartir  %s porque el backend que comparte %s no pudo encontrar su origen",
    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos",
    "%s shared »%s« with you" : "%s ha compartido  »%s« con usted",
    "%s via %s" : "%s por %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La aplicación \"%s\" no puede ser instalada porque las siguientes dependencias no están satisfechas: %s "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.1.zip: nextcloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Se ha detectado la configuración de muestra",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que la configuración de muestra ha sido copiada. Esto puede descomponer su instalacón y no está soportado. Favor de leer la documentación antes de hacer cambios en el archivo config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de Groupware",
    "Social sharing bundle" : "Paquete para compartir en redes sociales",
    "PHP %s or higher is required." : "Se requiere de PHPH %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferiror a la %s es requerido. ",
    "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
    "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
    "The library %s is not available." : "La biblioteca %s no está disponible. ",
    "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
    "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Favor de habilitarlo en sus configuraciones de aplicación o contacte a su administrador.  ",
    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
    "__language_name__" : "Español (Argentina)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
    "Help" : "Ayuda",
    "Apps" : "Aplicaciones",
    "Settings" : "Ajustes",
    "Log out" : "Cerrar sesión",
    "Users" : "Usuarios",
    "Email" : "Correo electrónico",
    "Phone" : "Teléfono fijo",
    "Twitter" : "Twitter",
    "Website" : "Sitio web",
    "Address" : "Dirección",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Full name" : "Nombre completo",
    "Unknown user" : "Ususario desconocido",
    "Additional settings" : "Configuraciones adicionales",
    "You need to enter details of an existing account." : "Necesita ingresar los detalles de una cuenta existente.",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña de Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "El nombre de usuario y/o contraseña de PostgreSQL inválidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Uselo bajo su propio riesgo!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, favor de cosiderar usar en su lugar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Favor de eliminar el ajuste open_basedir de su archivo php.ini o cambie a PHP de 64 bits. ",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Establecer la contraseña del administrador.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
    "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
    "Open »%s«" : "Abrir »%s«",
    "You are not allowed to share %s" : "No tiene permitido compartir %s",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el nombre de usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre del usuario contiene un espacio en blanco al inicio o al final",
    "Username must not consist of dots only" : "El nombre de usuario no debe consistir de solo puntos. ",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The username is already being used" : "Ese nombre de usuario ya está en uso",
    "User disabled" : "Usuario deshabilitado",
    "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, favor de intentarlo más tarde. ",
    "Application is not enabled" : "La aplicación está deshabilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "La ficha ha expirado. Favor de recarga la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuenta con controladores de base de datos (sqlite, mysql o postgresql)  instalados. ",
    "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
    "Please ask your server administrator to install the module." : "Favor de solicitar a su adminsitrador la instalación del módulo. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s esta instalado. ",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, favor de actualizar la versión de su libxml2 y reinicie su servidor web. ",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
    "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
    "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
    "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
    "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
    "%s enter the database username and name." : "%s ingrese el nombre del usuario y nombre de la base de datos",
    "%s enter the database username." : "%s ingresar el nombre de usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s no puede utilizar puntos en el nombre de la base de datos",
    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Favor de ver %s",
    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Favor de ver %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Favor de ver %s.",
    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
    "Please install one of these locales on your system and restart your webserver." : "Favor de instalar uno de las siguientes configuraciones locales en su sistema y reinicie su servidor web",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establezca <code>mbstring.func_overload</code> a <code>0</code> en su archivo php.ini",
    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
    "Please upgrade your database version" : "Favor de actualizar la versión de la base de datos",
    "Your data directory is readable by other users" : "Su direcctorio data puede ser leído por otros usuarios",
    "Your data directory must be an absolute path" : "Su direcctorio data debe ser una ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Verifique el valor de \"datadirectory\" en su configuración",
    "Your data directory is invalid" : "Su directorio de datos es inválido"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
